@@ -14,6 +14,7 @@ from celery import Celery
 from render import RENDER_DIR, LOG_DIR
 from render.logger import configure_logger
 from render.s3 import S3, AWS_S3
+from render.watch.logs import collect_instance_logs
 
 celery = Celery()
 celery.config_from_object('render.celeryconfig')
@@ -84,7 +85,7 @@ class FollowLog:
         # noinspection PyTypeChecker
         with open(self.workdir / 'rendering.log', 'wb') as f:
             for s in stdout:
-                # remove ASCII NULL symbol
+                # remove ASCII NULL symbol inplace
                 part = s.replace(b'\x00', b'')
                 f.write(part)
                 f.flush()
@@ -151,6 +152,7 @@ class Render:
             f'-outputName:{str(self.scene.workdir / f"0.{extension}")}',
         ]
         if self.texture:
+            logger.debug(f"Using textures: {self.texture.dst.glob('*')}")
             args.append(f'-bitmapPath:{self.texture.dst}')
         args.append(str(self.scene.localfile))
         logger.debug(f"Params = {args}")
@@ -214,6 +216,7 @@ def run(scene_key, texture=None):
         raise
     finally:
         collect_logs(scene, s3)
+        collect_instance_logs(s3)
 
 
 celery.task(name="run")(run)
