@@ -1,7 +1,6 @@
 import glob
 import itertools
 import logging
-import os
 from pathlib import PurePosixPath, Path
 
 from render import RENDER_DIR, LOG_DIR
@@ -12,7 +11,7 @@ logger = logging.getLogger(__name__)
 
 
 def collect_instance_logs(client: S3):
-    logger.debug("Collecting log files...")
+    logger.debug("Collecting log files for instance...")
     for path in itertools.chain(
             # additional logs could be appended here
             glob.glob(str(RENDER_DIR / '**' / '*.log')),
